const webpack = require('webpack');
const path = require('path');
const packageJson = require('./package.json');
const WebpackMd5Hash = require('webpack-md5-hash');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const OptimizeCssAssetsPlugin = require('optimize-css-assets-webpack-plugin');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const ManifestPlugin = require('webpack-manifest-plugin');

module.exports = {
  entry: [
    'babel-polyfill',
    './src/index.js',
  ],
  output: {
    chunkFilename: 'bundle.[name].[chunkhash].js',
    path: path.join(__dirname, 'dist'),
    filename: 'bundle.[name].[chunkhash].js',
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        loaders: [
          'babel-loader',
          'eslint-loader',
        ],
      },
      {
        test: /\.css$/,
        loader: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: 'css-loader?modules=true&localIdentName=[name]__[local]___[hash:base64:5]!postcss-loader',
        }),
      },
      {
        test: /\.html$/,
        loader: 'html-loader',
        options: {
          minimize: true,
        },
      },
      {
        test: /\.(png|jpg|gif|svg)$/,
        use: [
          {
            loader: 'url-loader',
            options: {
              limit: 8192,
            },
          },
        ],
      },
    ],
  },
  plugins: [
    // set global vars
    new webpack.DefinePlugin({
      'process.env': {
        // Useful to reduce the size of client-side libraries, e.g. react
        NODE_ENV: JSON.stringify('production'),
      },
    }),
    // md5 chunkhashes
    new WebpackMd5Hash(),
    // Html
    new HtmlWebpackPlugin({
      favicon: './src/assets/favicon.ico',
      filename: 'index.html',
      template: './src/index.html',
    }),
    // Css
    new ExtractTextPlugin({ filename: 'bundle.[hash].css', allChunks: true }),
    new OptimizeCssAssetsPlugin({
      cssProcessorOptions: { discardComments: { removeAll: true } },
    }),
    // Js
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        warnings: false,
      },
    }),
    new ManifestPlugin({
      seed: {
        author: packageJson.author,
        description: packageJson.description,
        icons: [
          {
            src: 'favicon.ico',
            sizes: '64x64',
            type: 'image/png',
          },
        ],
        name: packageJson.name,
        short_name: packageJson.name,
        version: packageJson.version,
      },
    }),
  ],
};
